==> org-lsst-sal-cccamera-2.5.0-sources.jar: org/lsst/sal/cccamera/event/Quadbox_PDU_24VD_LimitsConfigurationEvent.java <==
package org.lsst.sal.cccamera.event;

import org.lsst.sal.camera.CameraEvent;

public class Quadbox_PDU_24VD_LimitsConfigurationEvent extends CameraEvent {
  private final String version;

  private final double board_T_warnHi;

  private final double board_T_warnLo;

  private final double board_T_limitHi;

  private final double board_T_limitLo;

  private final double fes_I_warnHi;

  private final double fes_I_warnLo;

  private final double fes_I_limitHi;

  private final double fes_I_limitLo;

  private final double fes_V_warnHi;

  private final double fes_V_warnLo;

  private final double fes_V_limitHi;

  private final double fes_V_limitLo;

  private final double fpga_T_warnHi;

  private final double fpga_T_warnLo;

  private final double fpga_T_limitHi;

  private final double fpga_T_limitLo;

  private final double main_I_warnHi;

  private final double main_I_warnLo;

  private final double main_I_limitHi;

  private final double main_I_limitLo;

  private final double main_T_warnHi;

  private final double main_T_warnLo;

  private final double main_T_limitHi;

  private final double main_T_limitLo;

  private final double main_V_warnHi;

  private final double main_V_warnLo;

  private final double main_V_limitHi;

  private final double main_V_limitLo;

  public Quadbox_PDU_24VD_LimitsConfigurationEvent(int priority, String version,
      double board_T_warnHi, double board_T_warnLo, double board_T_limitHi, double board_T_limitLo,
      double fes_I_warnHi, double fes_I_warnLo, double fes_I_limitHi, double fes_I_limitLo,
      double fes_V_warnHi, double fes_V_warnLo, double fes_V_limitHi, double fes_V_limitLo,
      double fpga_T_warnHi, double fpga_T_warnLo, double fpga_T_limitHi, double fpga_T_limitLo,
      double main_I_warnHi, double main_I_warnLo, double main_I_limitHi, double main_I_limitLo,
      double main_T_warnHi, double main_T_warnLo, double main_T_limitHi, double main_T_limitLo,
      double main_V_warnHi, double main_V_warnLo, double main_V_limitHi, double main_V_limitLo) {
    super (priority);
    this.version = version;
    this.board_T_warnHi = board_T_warnHi;
    this.board_T_warnLo = board_T_warnLo;
    this.board_T_limitHi = board_T_limitHi;
    this.board_T_limitLo = board_T_limitLo;
    this.fes_I_warnHi = fes_I_warnHi;
    this.fes_I_warnLo = fes_I_warnLo;
    this.fes_I_limitHi = fes_I_limitHi;
    this.fes_I_limitLo = fes_I_limitLo;
    this.fes_V_warnHi = fes_V_warnHi;
    this.fes_V_warnLo = fes_V_warnLo;
    this.fes_V_limitHi = fes_V_limitHi;
    this.fes_V_limitLo = fes_V_limitLo;
    this.fpga_T_warnHi = fpga_T_warnHi;
    this.fpga_T_warnLo = fpga_T_warnLo;
    this.fpga_T_limitHi = fpga_T_limitHi;
    this.fpga_T_limitLo = fpga_T_limitLo;
    this.main_I_warnHi = main_I_warnHi;
    this.main_I_warnLo = main_I_warnLo;
    this.main_I_limitHi = main_I_limitHi;
    this.main_I_limitLo = main_I_limitLo;
    this.main_T_warnHi = main_T_warnHi;
    this.main_T_warnLo = main_T_warnLo;
    this.main_T_limitHi = main_T_limitHi;
    this.main_T_limitLo = main_T_limitLo;
    this.main_V_warnHi = main_V_warnHi;
    this.main_V_warnLo = main_V_warnLo;
    this.main_V_limitHi = main_V_limitHi;
    this.main_V_limitLo = main_V_limitLo;
  }

  public String getVersion() {
    return version;
  }

  public double getBoard_T_warnHi() {
    return board_T_warnHi;
  }

  public double getBoard_T_warnLo() {
    return board_T_warnLo;
  }

  public double getBoard_T_limitHi() {
    return board_T_limitHi;
  }

  public double getBoard_T_limitLo() {
    return board_T_limitLo;
  }

  public double getFes_I_warnHi() {
    return fes_I_warnHi;
  }

  public double getFes_I_warnLo() {
    return fes_I_warnLo;
  }

  public double getFes_I_limitHi() {
    return fes_I_limitHi;
  }

  public double getFes_I_limitLo() {
    return fes_I_limitLo;
  }

  public double getFes_V_warnHi() {
    return fes_V_warnHi;
  }

  public double getFes_V_warnLo() {
    return fes_V_warnLo;
  }

  public double getFes_V_limitHi() {
    return fes_V_limitHi;
  }

  public double getFes_V_limitLo() {
    return fes_V_limitLo;
  }

  public double getFpga_T_warnHi() {
    return fpga_T_warnHi;
  }

  public double getFpga_T_warnLo() {
    return fpga_T_warnLo;
  }

  public double getFpga_T_limitHi() {
    return fpga_T_limitHi;
  }

  public double getFpga_T_limitLo() {
    return fpga_T_limitLo;
  }

  public double getMain_I_warnHi() {
    return main_I_warnHi;
  }

  public double getMain_I_warnLo() {
    return main_I_warnLo;
  }

  public double getMain_I_limitHi() {
    return main_I_limitHi;
  }

  public double getMain_I_limitLo() {
    return main_I_limitLo;
  }

  public double getMain_T_warnHi() {
    return main_T_warnHi;
  }

  public double getMain_T_warnLo() {
    return main_T_warnLo;
  }

  public double getMain_T_limitHi() {
    return main_T_limitHi;
  }

  public double getMain_T_limitLo() {
    return main_T_limitLo;
  }

  public double getMain_V_warnHi() {
    return main_V_warnHi;
  }

  public double getMain_V_warnLo() {
    return main_V_warnLo;
  }

  public double getMain_V_limitHi() {
    return main_V_limitHi;
  }

  public double getMain_V_limitLo() {
    return main_V_limitLo;
  }

  @Override
  public String toString() {
    return "Quadbox_PDU_24VD_LimitsConfigurationEvent{" + "version=" + version +
        ", board_T_warnHi=" + board_T_warnHi +", board_T_warnLo=" + board_T_warnLo +
        ", board_T_limitHi=" + board_T_limitHi +", board_T_limitLo=" + board_T_limitLo +
        ", fes_I_warnHi=" + fes_I_warnHi +", fes_I_warnLo=" + fes_I_warnLo +
        ", fes_I_limitHi=" + fes_I_limitHi +", fes_I_limitLo=" + fes_I_limitLo +
        ", fes_V_warnHi=" + fes_V_warnHi +", fes_V_warnLo=" + fes_V_warnLo +
        ", fes_V_limitHi=" + fes_V_limitHi +", fes_V_limitLo=" + fes_V_limitLo +
        ", fpga_T_warnHi=" + fpga_T_warnHi +", fpga_T_warnLo=" + fpga_T_warnLo +
        ", fpga_T_limitHi=" + fpga_T_limitHi +", fpga_T_limitLo=" + fpga_T_limitLo +
        ", main_I_warnHi=" + main_I_warnHi +", main_I_warnLo=" + main_I_warnLo +
        ", main_I_limitHi=" + main_I_limitHi +", main_I_limitLo=" + main_I_limitLo +
        ", main_T_warnHi=" + main_T_warnHi +", main_T_warnLo=" + main_T_warnLo +
        ", main_T_limitHi=" + main_T_limitHi +", main_T_limitLo=" + main_T_limitLo +
        ", main_V_warnHi=" + main_V_warnHi +", main_V_warnLo=" + main_V_warnLo +
        ", main_V_limitHi=" + main_V_limitHi +", main_V_limitLo=" + main_V_limitLo +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private int priority;

    private String version;

    private double board_T_warnHi;

    private double board_T_warnLo;

    private double board_T_limitHi;

    private double board_T_limitLo;

    private double fes_I_warnHi;

    private double fes_I_warnLo;

    private double fes_I_limitHi;

    private double fes_I_limitLo;

    private double fes_V_warnHi;

    private double fes_V_warnLo;

    private double fes_V_limitHi;

    private double fes_V_limitLo;

    private double fpga_T_warnHi;

    private double fpga_T_warnLo;

    private double fpga_T_limitHi;

    private double fpga_T_limitLo;

    private double main_I_warnHi;

    private double main_I_warnLo;

    private double main_I_limitHi;

    private double main_I_limitLo;

    private double main_T_warnHi;

    private double main_T_warnLo;

    private double main_T_limitHi;

    private double main_T_limitLo;

    private double main_V_warnHi;

    private double main_V_warnLo;

    private double main_V_limitHi;

    private double main_V_limitLo;

    private Builder() {
    }

    public Builder priority(int priority) {
      this.priority = priority;
      return this;
    }

    public Builder version(String version) {
      this.version = version;
      return this;
    }

    public Builder board_T_warnHi(double board_T_warnHi) {
      this.board_T_warnHi = board_T_warnHi;
      return this;
    }

    public Builder board_T_warnLo(double board_T_warnLo) {
      this.board_T_warnLo = board_T_warnLo;
      return this;
    }

    public Builder board_T_limitHi(double board_T_limitHi) {
      this.board_T_limitHi = board_T_limitHi;
      return this;
    }

    public Builder board_T_limitLo(double board_T_limitLo) {
      this.board_T_limitLo = board_T_limitLo;
      return this;
    }

    public Builder fes_I_warnHi(double fes_I_warnHi) {
      this.fes_I_warnHi = fes_I_warnHi;
      return this;
    }

    public Builder fes_I_warnLo(double fes_I_warnLo) {
      this.fes_I_warnLo = fes_I_warnLo;
      return this;
    }

    public Builder fes_I_limitHi(double fes_I_limitHi) {
      this.fes_I_limitHi = fes_I_limitHi;
      return this;
    }

    public Builder fes_I_limitLo(double fes_I_limitLo) {
      this.fes_I_limitLo = fes_I_limitLo;
      return this;
    }

    public Builder fes_V_warnHi(double fes_V_warnHi) {
      this.fes_V_warnHi = fes_V_warnHi;
      return this;
    }

    public Builder fes_V_warnLo(double fes_V_warnLo) {
      this.fes_V_warnLo = fes_V_warnLo;
      return this;
    }

    public Builder fes_V_limitHi(double fes_V_limitHi) {
      this.fes_V_limitHi = fes_V_limitHi;
      return this;
    }

    public Builder fes_V_limitLo(double fes_V_limitLo) {
      this.fes_V_limitLo = fes_V_limitLo;
      return this;
    }

    public Builder fpga_T_warnHi(double fpga_T_warnHi) {
      this.fpga_T_warnHi = fpga_T_warnHi;
      return this;
    }

    public Builder fpga_T_warnLo(double fpga_T_warnLo) {
      this.fpga_T_warnLo = fpga_T_warnLo;
      return this;
    }

    public Builder fpga_T_limitHi(double fpga_T_limitHi) {
      this.fpga_T_limitHi = fpga_T_limitHi;
      return this;
    }

    public Builder fpga_T_limitLo(double fpga_T_limitLo) {
      this.fpga_T_limitLo = fpga_T_limitLo;
      return this;
    }

    public Builder main_I_warnHi(double main_I_warnHi) {
      this.main_I_warnHi = main_I_warnHi;
      return this;
    }

    public Builder main_I_warnLo(double main_I_warnLo) {
      this.main_I_warnLo = main_I_warnLo;
      return this;
    }

    public Builder main_I_limitHi(double main_I_limitHi) {
      this.main_I_limitHi = main_I_limitHi;
      return this;
    }

    public Builder main_I_limitLo(double main_I_limitLo) {
      this.main_I_limitLo = main_I_limitLo;
      return this;
    }

    public Builder main_T_warnHi(double main_T_warnHi) {
      this.main_T_warnHi = main_T_warnHi;
      return this;
    }

    public Builder main_T_warnLo(double main_T_warnLo) {
      this.main_T_warnLo = main_T_warnLo;
      return this;
    }

    public Builder main_T_limitHi(double main_T_limitHi) {
      this.main_T_limitHi = main_T_limitHi;
      return this;
    }

    public Builder main_T_limitLo(double main_T_limitLo) {
      this.main_T_limitLo = main_T_limitLo;
      return this;
    }

    public Builder main_V_warnHi(double main_V_warnHi) {
      this.main_V_warnHi = main_V_warnHi;
      return this;
    }

    public Builder main_V_warnLo(double main_V_warnLo) {
      this.main_V_warnLo = main_V_warnLo;
      return this;
    }

    public Builder main_V_limitHi(double main_V_limitHi) {
      this.main_V_limitHi = main_V_limitHi;
      return this;
    }

    public Builder main_V_limitLo(double main_V_limitLo) {
      this.main_V_limitLo = main_V_limitLo;
      return this;
    }

    public Quadbox_PDU_24VD_LimitsConfigurationEvent build() {
      return new Quadbox_PDU_24VD_LimitsConfigurationEvent(priority, version, board_T_warnHi, board_T_warnLo, board_T_limitHi, board_T_limitLo, fes_I_warnHi, fes_I_warnLo, fes_I_limitHi, fes_I_limitLo, fes_V_warnHi, fes_V_warnLo, fes_V_limitHi, fes_V_limitLo, fpga_T_warnHi, fpga_T_warnLo, fpga_T_limitHi, fpga_T_limitLo, main_I_warnHi, main_I_warnLo, main_I_limitHi, main_I_limitLo, main_T_warnHi, main_T_warnLo, main_T_limitHi, main_T_limitLo, main_V_warnHi, main_V_warnLo, main_V_limitHi, main_V_limitLo);
    }
  }
}

==> org-lsst-sal-cccamera-3.0.0-sources.jar: org/lsst/sal/cccamera/event/Quadbox_PDU_24VD_LimitsConfigurationEvent.java <==
package org.lsst.sal.cccamera.event;

import org.lsst.sal.camera.CameraEvent;

public class Quadbox_PDU_24VD_LimitsConfigurationEvent extends CameraEvent {
  private final String version;

  private final double board_T_warnHi;

  private final double board_T_warnLo;

  private final double board_T_limitHi;

  private final double board_T_limitLo;

  private final double fes_I_warnHi;

  private final double fes_I_warnLo;

  private final double fes_I_limitHi;

  private final double fes_I_limitLo;

  private final double fes_V_warnHi;

  private final double fes_V_warnLo;

  private final double fes_V_limitHi;

  private final double fes_V_limitLo;

  private final double fpga_T_warnHi;

  private final double fpga_T_warnLo;

  private final double fpga_T_limitHi;

  private final double fpga_T_limitLo;

  private final double main_I_warnHi;

  private final double main_I_warnLo;

  private final double main_I_limitHi;

  private final double main_I_limitLo;

  private final double main_T_warnHi;

  private final double main_T_warnLo;

  private final double main_T_limitHi;

  private final double main_T_limitLo;

  private final double main_V_warnHi;

  private final double main_V_warnLo;

  private final double main_V_limitHi;

  private final double main_V_limitLo;

  public Quadbox_PDU_24VD_LimitsConfigurationEvent(String version, double board_T_warnHi,
      double board_T_warnLo, double board_T_limitHi, double board_T_limitLo, double fes_I_warnHi,
      double fes_I_warnLo, double fes_I_limitHi, double fes_I_limitLo, double fes_V_warnHi,
      double fes_V_warnLo, double fes_V_limitHi, double fes_V_limitLo, double fpga_T_warnHi,
      double fpga_T_warnLo, double fpga_T_limitHi, double fpga_T_limitLo, double main_I_warnHi,
      double main_I_warnLo, double main_I_limitHi, double main_I_limitLo, double main_T_warnHi,
      double main_T_warnLo, double main_T_limitHi, double main_T_limitLo, double main_V_warnHi,
      double main_V_warnLo, double main_V_limitHi, double main_V_limitLo) {
    this.version = version;
    this.board_T_warnHi = board_T_warnHi;
    this.board_T_warnLo = board_T_warnLo;
    this.board_T_limitHi = board_T_limitHi;
    this.board_T_limitLo = board_T_limitLo;
    this.fes_I_warnHi = fes_I_warnHi;
    this.fes_I_warnLo = fes_I_warnLo;
    this.fes_I_limitHi = fes_I_limitHi;
    this.fes_I_limitLo = fes_I_limitLo;
    this.fes_V_warnHi = fes_V_warnHi;
    this.fes_V_warnLo = fes_V_warnLo;
    this.fes_V_limitHi = fes_V_limitHi;
    this.fes_V_limitLo = fes_V_limitLo;
    this.fpga_T_warnHi = fpga_T_warnHi;
    this.fpga_T_warnLo = fpga_T_warnLo;
    this.fpga_T_limitHi = fpga_T_limitHi;
    this.fpga_T_limitLo = fpga_T_limitLo;
    this.main_I_warnHi = main_I_warnHi;
    this.main_I_warnLo = main_I_warnLo;
    this.main_I_limitHi = main_I_limitHi;
    this.main_I_limitLo = main_I_limitLo;
    this.main_T_warnHi = main_T_warnHi;
    this.main_T_warnLo = main_T_warnLo;
    this.main_T_limitHi = main_T_limitHi;
    this.main_T_limitLo = main_T_limitLo;
    this.main_V_warnHi = main_V_warnHi;
    this.main_V_warnLo = main_V_warnLo;
    this.main_V_limitHi = main_V_limitHi;
    this.main_V_limitLo = main_V_limitLo;
  }

  public String getVersion() {
    return version;
  }

  public double getBoard_T_warnHi() {
    return board_T_warnHi;
  }

  public double getBoard_T_warnLo() {
    return board_T_warnLo;
  }

  public double getBoard_T_limitHi() {
    return board_T_limitHi;
  }

  public double getBoard_T_limitLo() {
    return board_T_limitLo;
  }

  public double getFes_I_warnHi() {
    return fes_I_warnHi;
  }

  public double getFes_I_warnLo() {
    return fes_I_warnLo;
  }

  public double getFes_I_limitHi() {
    return fes_I_limitHi;
  }

  public double getFes_I_limitLo() {
    return fes_I_limitLo;
  }

  public double getFes_V_warnHi() {
    return fes_V_warnHi;
  }

  public double getFes_V_warnLo() {
    return fes_V_warnLo;
  }

  public double getFes_V_limitHi() {
    return fes_V_limitHi;
  }

  public double getFes_V_limitLo() {
    return fes_V_limitLo;
  }

  public double getFpga_T_warnHi() {
    return fpga_T_warnHi;
  }

  public double getFpga_T_warnLo() {
    return fpga_T_warnLo;
  }

  public double getFpga_T_limitHi() {
    return fpga_T_limitHi;
  }

  public double getFpga_T_limitLo() {
    return fpga_T_limitLo;
  }

  public double getMain_I_warnHi() {
    return main_I_warnHi;
  }

  public double getMain_I_warnLo() {
    return main_I_warnLo;
  }

  public double getMain_I_limitHi() {
    return main_I_limitHi;
  }

  public double getMain_I_limitLo() {
    return main_I_limitLo;
  }

  public double getMain_T_warnHi() {
    return main_T_warnHi;
  }

  public double getMain_T_warnLo() {
    return main_T_warnLo;
  }

  public double getMain_T_limitHi() {
    return main_T_limitHi;
  }

  public double getMain_T_limitLo() {
    return main_T_limitLo;
  }

  public double getMain_V_warnHi() {
    return main_V_warnHi;
  }

  public double getMain_V_warnLo() {
    return main_V_warnLo;
  }

  public double getMain_V_limitHi() {
    return main_V_limitHi;
  }

  public double getMain_V_limitLo() {
    return main_V_limitLo;
  }

  @Override
  public String toString() {
    return "Quadbox_PDU_24VD_LimitsConfigurationEvent{" + "version=" + version +
        ", board_T_warnHi=" + board_T_warnHi +", board_T_warnLo=" + board_T_warnLo +
        ", board_T_limitHi=" + board_T_limitHi +", board_T_limitLo=" + board_T_limitLo +
        ", fes_I_warnHi=" + fes_I_warnHi +", fes_I_warnLo=" + fes_I_warnLo +
        ", fes_I_limitHi=" + fes_I_limitHi +", fes_I_limitLo=" + fes_I_limitLo +
        ", fes_V_warnHi=" + fes_V_warnHi +", fes_V_warnLo=" + fes_V_warnLo +
        ", fes_V_limitHi=" + fes_V_limitHi +", fes_V_limitLo=" + fes_V_limitLo +
        ", fpga_T_warnHi=" + fpga_T_warnHi +", fpga_T_warnLo=" + fpga_T_warnLo +
        ", fpga_T_limitHi=" + fpga_T_limitHi +", fpga_T_limitLo=" + fpga_T_limitLo +
        ", main_I_warnHi=" + main_I_warnHi +", main_I_warnLo=" + main_I_warnLo +
        ", main_I_limitHi=" + main_I_limitHi +", main_I_limitLo=" + main_I_limitLo +
        ", main_T_warnHi=" + main_T_warnHi +", main_T_warnLo=" + main_T_warnLo +
        ", main_T_limitHi=" + main_T_limitHi +", main_T_limitLo=" + main_T_limitLo +
        ", main_V_warnHi=" + main_V_warnHi +", main_V_warnLo=" + main_V_warnLo +
        ", main_V_limitHi=" + main_V_limitHi +", main_V_limitLo=" + main_V_limitLo +"}";
  }

  public static Builder builder() {
    return new Builder();
  }

  public static class Builder {
    private String version;

    private double board_T_warnHi;

    private double board_T_warnLo;

    private double board_T_limitHi;

    private double board_T_limitLo;

    private double fes_I_warnHi;

    private double fes_I_warnLo;

    private double fes_I_limitHi;

    private double fes_I_limitLo;

    private double fes_V_warnHi;

    private double fes_V_warnLo;

    private double fes_V_limitHi;

    private double fes_V_limitLo;

    private double fpga_T_warnHi;

    private double fpga_T_warnLo;

    private double fpga_T_limitHi;

    private double fpga_T_limitLo;

    private double main_I_warnHi;

    private double main_I_warnLo;

    private double main_I_limitHi;

    private double main_I_limitLo;

    private double main_T_warnHi;

    private double main_T_warnLo;

    private double main_T_limitHi;

    private double main_T_limitLo;

    private double main_V_warnHi;

    private double main_V_warnLo;

    private double main_V_limitHi;

    private double main_V_limitLo;

    private Builder() {
    }

    public Builder version(String version) {
      this.version = version;
      return this;
    }

    public Builder board_T_warnHi(double board_T_warnHi) {
      this.board_T_warnHi = board_T_warnHi;
      return this;
    }

    public Builder board_T_warnLo(double board_T_warnLo) {
      this.board_T_warnLo = board_T_warnLo;
      return this;
    }

    public Builder board_T_limitHi(double board_T_limitHi) {
      this.board_T_limitHi = board_T_limitHi;
      return this;
    }

    public Builder board_T_limitLo(double board_T_limitLo) {
      this.board_T_limitLo = board_T_limitLo;
      return this;
    }

    public Builder fes_I_warnHi(double fes_I_warnHi) {
      this.fes_I_warnHi = fes_I_warnHi;
      return this;
    }

    public Builder fes_I_warnLo(double fes_I_warnLo) {
      this.fes_I_warnLo = fes_I_warnLo;
      return this;
    }

    public Builder fes_I_limitHi(double fes_I_limitHi) {
      this.fes_I_limitHi = fes_I_limitHi;
      return this;
    }

    public Builder fes_I_limitLo(double fes_I_limitLo) {
      this.fes_I_limitLo = fes_I_limitLo;
      return this;
    }

    public Builder fes_V_warnHi(double fes_V_warnHi) {
      this.fes_V_warnHi = fes_V_warnHi;
      return this;
    }

    public Builder fes_V_warnLo(double fes_V_warnLo) {
      this.fes_V_warnLo = fes_V_warnLo;
      return this;
    }

    public Builder fes_V_limitHi(double fes_V_limitHi) {
      this.fes_V_limitHi = fes_V_limitHi;
      return this;
    }

    public Builder fes_V_limitLo(double fes_V_limitLo) {
      this.fes_V_limitLo = fes_V_limitLo;
      return this;
    }

    public Builder fpga_T_warnHi(double fpga_T_warnHi) {
      this.fpga_T_warnHi = fpga_T_warnHi;
      return this;
    }

    public Builder fpga_T_warnLo(double fpga_T_warnLo) {
      this.fpga_T_warnLo = fpga_T_warnLo;
      return this;
    }

    public Builder fpga_T_limitHi(double fpga_T_limitHi) {
      this.fpga_T_limitHi = fpga_T_limitHi;
      return this;
    }

    public Builder fpga_T_limitLo(double fpga_T_limitLo) {
      this.fpga_T_limitLo = fpga_T_limitLo;
      return this;
    }

    public Builder main_I_warnHi(double main_I_warnHi) {
      this.main_I_warnHi = main_I_warnHi;
      return this;
    }

    public Builder main_I_warnLo(double main_I_warnLo) {
      this.main_I_warnLo = main_I_warnLo;
      return this;
    }

    public Builder main_I_limitHi(double main_I_limitHi) {
      this.main_I_limitHi = main_I_limitHi;
      return this;
    }

    public Builder main_I_limitLo(double main_I_limitLo) {
      this.main_I_limitLo = main_I_limitLo;
      return this;
    }

    public Builder main_T_warnHi(double main_T_warnHi) {
      this.main_T_warnHi = main_T_warnHi;
      return this;
    }

    public Builder main_T_warnLo(double main_T_warnLo) {
      this.main_T_warnLo = main_T_warnLo;
      return this;
    }

    public Builder main_T_limitHi(double main_T_limitHi) {
      this.main_T_limitHi = main_T_limitHi;
      return this;
    }

    public Builder main_T_limitLo(double main_T_limitLo) {
      this.main_T_limitLo = main_T_limitLo;
      return this;
    }

    public Builder main_V_warnHi(double main_V_warnHi) {
      this.main_V_warnHi = main_V_warnHi;
      return this;
    }

    public Builder main_V_warnLo(double main_V_warnLo) {
      this.main_V_warnLo = main_V_warnLo;
      return this;
    }

    public Builder main_V_limitHi(double main_V_limitHi) {
      this.main_V_limitHi = main_V_limitHi;
      return this;
    }

    public Builder main_V_limitLo(double main_V_limitLo) {
      this.main_V_limitLo = main_V_limitLo;
      return this;
    }

    public Quadbox_PDU_24VD_LimitsConfigurationEvent build() {
      return new Quadbox_PDU_24VD_LimitsConfigurationEvent(version, board_T_warnHi, board_T_warnLo, board_T_limitHi, board_T_limitLo, fes_I_warnHi, fes_I_warnLo, fes_I_limitHi, fes_I_limitLo, fes_V_warnHi, fes_V_warnLo, fes_V_limitHi, fes_V_limitLo, fpga_T_warnHi, fpga_T_warnLo, fpga_T_limitHi, fpga_T_limitLo, main_I_warnHi, main_I_warnLo, main_I_limitHi, main_I_limitLo, main_T_warnHi, main_T_warnLo, main_T_limitHi, main_T_limitLo, main_V_warnHi, main_V_warnLo, main_V_limitHi, main_V_limitLo);
    }
  }
}
